"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const postcss_1 = __importDefault(require("postcss"));
const tailwindcss_1 = __importDefault(require("tailwindcss"));
const vitest_1 = require("vitest");
const index_1 = __importDefault(require("./index"));
let html = String.raw;
function run(input, config, plugin = tailwindcss_1.default) {
    let { currentTestName } = vitest_1.expect.getState();
    return (0, postcss_1.default)(plugin(config)).process(input, {
        from: `${path_1.default.resolve(__filename)}?test=${currentTestName}`,
    });
}
(0, vitest_1.it)("should generate stateful data attributes", () => __awaiter(void 0, void 0, void 0, function* () {
    let config = {
        content: [
            {
                raw: html `
          <div class="radix-state-open:opacity-50" />
          <div class="group">
            <div class="group-radix-state-open:cursor-not-allowed" />
          </div>
          <div class="peer" />
          <div class="peer-radix-state-open:cursor-not-allowed" />
        `,
            },
        ],
        plugins: [index_1.default],
    };
    return run("@tailwind utilities", config).then((result) => {
        (0, vitest_1.expect)(result.css).toMatchSnapshot();
    });
}));
(0, vitest_1.it)("should generate static data attributes", () => __awaiter(void 0, void 0, void 0, function* () {
    let config = {
        content: [
            {
                raw: html `
          <div class="radix-disabled:opacity-50" />
          <div class="group">
            <div class="group-radix-disabled:cursor-not-allowed" />
          </div>
          <div class="peer" />
          <div class="peer-radix-disabled:cursor-not-allowed" />

          <div class="radix-highlighted:opacity-50" />
          <div class="group">
            <div class="group-radix-highlighted:cursor-not-allowed" />
          </div>
          <div class="peer" />
          <div class="peer-radix-highlighted:cursor-not-allowed" />

          <div class="radix-placeholder:opacity-50" />
          <div class="group">
            <div class="group-radix-placeholder:cursor-not-allowed" />
          </div>
          <div class="peer" />
          <div class="peer-radix-placeholder:cursor-not-allowed" />
        `,
            },
        ],
        plugins: [index_1.default],
    };
    return run("@tailwind utilities", config).then((result) => {
        (0, vitest_1.expect)(result.css).toMatchSnapshot();
    });
}));
(0, vitest_1.it)("should generate transform origins", () => __awaiter(void 0, void 0, void 0, function* () {
    let config = {
        content: [
            {
                raw: html `
          <div class="origin-radix-context-menu" />
          <div class="origin-radix-hover-card" />
          <div class="origin-radix-menubar" />
          <div class="origin-radix-popover" />
          <div class="origin-radix-select" />
          <div class="origin-radix-tooltip" />
        `,
            },
        ],
        plugins: [index_1.default],
    };
    return run("@tailwind utilities", config).then((result) => {
        (0, vitest_1.expect)(result.css).toMatchSnapshot();
    });
}));
(0, vitest_1.it)("should generate tooltip transoforms", () => __awaiter(void 0, void 0, void 0, function* () {
    let config = {
        content: [
            {
                raw: html `
          <div class="translate-x-radix-toast-swipe-end-x" />
          <div class="translate-y-radix-toast-swipe-end-y" />
          <div class="translate-x-radix-toast-swipe-move-x" />
          <div class="translate-y-radix-toast-swipe-move-y" />
        `,
            },
        ],
        plugins: [index_1.default],
    };
    return run("@tailwind utilities", config).then((result) => {
        (0, vitest_1.expect)(result.css).toMatchSnapshot();
    });
}));
(0, vitest_1.it)("should generate tooltip dimensions", () => __awaiter(void 0, void 0, void 0, function* () {
    let config = {
        content: [
            {
                raw: html `
          <div class="w-radix-navigation-menu-viewport" />
          <div class="h-radix-navigation-menu-viewport" />
          <div class="w-radix-accordion-content" />
          <div class="h-radix-accordion-content" />
          <div class="w-radix-collapsible-content" />
          <div class="h-radix-collapsible-content" />
        `,
            },
        ],
        plugins: [index_1.default],
    };
    return run("@tailwind utilities", config).then((result) => {
        (0, vitest_1.expect)(result.css).toMatchSnapshot();
    });
}));
(0, vitest_1.it)("should generate dimension origins", () => __awaiter(void 0, void 0, void 0, function* () {
    let config = {
        content: [
            {
                raw: html `
          <div class="w-radix-context-menu" />
          <div class="max-w-radix-context-menu-content-available-width" />
          <div class="h-radix-context-menu-content-available-height" />
          <div class="max-h-radix-context-menu-content-available-height" />
          <div class="w-radix-context-menu-trigger-width" />
          <div class="h-radix-context-menu-trigger-height" />

          <div class="w-radix-dropdown-menu" />
          <div class="max-w-radix-dropdown-menu-content-available-width" />
          <div class="h-radix-dropdown-menu-content-available-height" />
          <div class="max-h-radix-dropdown-menu-content-available-height" />
          <div class="w-radix-dropdown-menu-trigger-width" />
          <div class="h-radix-dropdown-menu-trigger-height" />

          <div class="w-radix-hover-card" />
          <div class="max-w-radix-hover-card-content-available-width" />
          <div class="h-radix-hover-card-content-available-height" />
          <div class="max-h-radix-hover-card-content-available-height" />
          <div class="w-radix-hover-card-trigger-width" />
          <div class="h-radix-hover-card-trigger-height" />

          <div class="w-radix-menubar" />
          <div class="max-w-radix-menubar-content-available-width" />
          <div class="h-radix-menubar-content-available-height" />
          <div class="max-h-radix-menubar-content-available-height" />
          <div class="w-radix-menubar-trigger-width" />
          <div class="h-radix-menubar-trigger-height" />

          <div class="w-radix-popover" />
          <div class="max-w-radix-popover-content-available-width" />
          <div class="h-radix-popover-content-available-height" />
          <div class="max-h-radix-popover-content-available-height" />
          <div class="w-radix-popover-trigger-width" />
          <div class="h-radix-popover-trigger-height" />

          <div class="w-radix-select" />
          <div class="max-w-radix-select-content-available-width" />
          <div class="h-radix-select-content-available-height" />
          <div class="max-h-radix-select-content-available-height" />
          <div class="w-radix-select-trigger-width" />
          <div class="h-radix-select-trigger-height" />

          <div class="w-radix-tooltip" />
          <div class="max-w-radix-tooltip-content-available-width" />
          <div class="h-radix-tooltip-content-available-height" />
          <div class="max-h-radix-tooltip-content-available-height" />
          <div class="w-radix-tooltip-trigger-width" />
          <div class="h-radix-tooltip-trigger-height" />
        `,
            },
        ],
        plugins: [index_1.default],
    };
    return run("@tailwind utilities", config).then((result) => {
        (0, vitest_1.expect)(result.css).toMatchSnapshot();
    });
}));
